Helpviewer/HelpClearPrivateDataDialog.py

changeset 4612
c9982bcd00f8
parent 4021
195a471c327b
child 4631
5c1a96925da4
diff -r 93732395fc1d -r c9982bcd00f8 Helpviewer/HelpClearPrivateDataDialog.py
--- a/Helpviewer/HelpClearPrivateDataDialog.py	Sun Dec 06 14:54:10 2015 +0100
+++ b/Helpviewer/HelpClearPrivateDataDialog.py	Sun Dec 06 19:09:32 2015 +0100
@@ -36,8 +36,9 @@
         
         @return tuple with flags indicating which data to clear
             (browsing history, search history, favicons, disk cache, cookies,
-            passwords, web databases, downloads, flash) and the selected
-            history period in milliseconds (tuple of booleans and integer)
+            passwords, web databases, downloads, flash, zoom values) and the
+            selected history period in milliseconds (tuple of booleans and
+            integer)
         """
         index = self.historyCombo.currentIndex()
         if index == 0:
@@ -65,4 +66,5 @@
                 self.databasesCheckBox.isChecked(),
                 self.downloadsCheckBox.isChecked(),
                 self.flashCookiesCheckBox.isChecked(),
+                self.zoomCheckBox.isChecked(),
                 historyPeriod)

eric ide

mercurial